***********************************************************************************
*InflacionVerdadera.com
*SCRIPT: Indice de Precios Venezuela - Por Categoria
*Fecha: Junio 2017
*Nota: Indice experimental con data recolectada por telefonos mobiles y crowdsourcing
***********************************************************************************

****SETUP***********
**Configurar el directorio donde esta la data
global dir "C:\inflacionverdadera\venezuela"

**********************

*Carga la data
use "${dir}\inflacionverdadera_venezuela_microdata.dta", clear

*Completar panel
tsfill 
gen miss=1 if price==.
foreach var in CODIGODEBARRAS NOMBRETIENDA CIUDAD CODIGOPOSTAL CATEGORIA {
replace `var'=`var'[_n-1] if `var'=="" & id==id[_n-1]
}

*Arrastrar precios cuando hay un gap en la data
replace price=l.price if price==.

*****Calcular Indice ponderado por categorias

*Traer ponderaciones por categoria
ren CATEGORIA category
replace category=trim(category)
merge m:1 category using "${dir}\\ponderaciones.dta"
keep if _merge==3
drop _merge

*Lista de diferentes categorias
levelsof cat, clean
global listcat `r(levels)'

*grabar archivo temporario
save ${dir}\resultados\temp_cat.dta, replace

*Crear indice por categoria
foreach cat in $listcat {
noisily capture {
use ${dir}\resultados\temp_cat.dta, clear
keep if cat==`cat'

*Indice de Precio 
******************************************TODO
*Cambios de precio a nivel producto
tsset id date
gen relative=price/l.price

*Contar observaciones, Productos, Ciudades, Tiendas
gen idtemp=id
replace idtemp=. if miss==1
bysort date: egen ids=count(idtemp)
egen unique_obs=count(idtemp) 
drop idtemp
egen unique_ids=nvals(id)
egen unique_ciudad=nvals(CIUDAD)
egen unique_tienda=nvals(NOMBRETIENDA)

*Promedio geometrico por dia
bysort date: egen mean_all=gmean(relative)
keep cat category date mean_all ids unique*

*Dejar una observacion por dia 
egen tag = tag(date)
keep if tag==1

*Completar panel nuevamente. En algunos casos el tsfill de los ids no es suficiente. Por ejemplo, alcohol y tabaco tienen un set de ids y luego un gap hasta que entran nuevos ids, distintos a los anteriores. 

tsset date
tsfill
replace mean_all=1 if mean_all==.


*Crear el indice a partir del dia 7 ya que antes no puede haber un cambio de precios porque en el mejor de los casos la recoleccion de datos es semanal.
egen daymin=min(date)
replace daymin=daymin+7
drop if date<daymin
gen index=100 if date==daymin
drop daymin

replace index=mean_all*index[_n-1] if index==.
label var index "Indice"

***************************************
*Inflacion Mensual 
***************************************

sort date
tsset date

*Inflacion Mensual
gen mensual=100*(index-index[_n-30])/index[_n-30]
format mensual  %9.1f

egen mindate=min(date)
egen maxdate=max(date)
gen days=maxdate-mindate

*********************************************************
*Guardar la data
save "${dir}\resultados\index_`cat'_temp.dta", replace

*Eliminar los ultimos 7 dias, ya que hay data que todavia no ha sido enviada/procesada
global now = date("$S_DATE","DMY")
drop if date>=$now-7

*Graba Archivo en formato Stata
save "${dir}\resultados\index_`cat'.dta", replace

*Grabar archivos en formato para los graficos de la pagina web
label var date "Date"
label var index "Index"
label var mensual "Monthly"

*Agregar la definicion de la variable para importar al grafico
expand 2 if _n == 1
sort date
tostring date, replace format(%tdDD/NN/YY) force
replace date="string" in 1

tostring index, replace format(%9.2f)  force
replace index="number" in 1

tostring mensual, replace format(%9.2f)  force
replace mensual="number" in 1


ren date Fecha
ren index Indice
ren mensual Mensual

export delimited Fecha Indice using "${dir}\resultados\ven_indice_`cat'.csv", replace
export delimited Fecha Mensual using "${dir}\resultados\ven_mensual_`cat'.csv",  replace

*Grabar archivo para website
drop if Mensual =="number"
export excel Fecha Indice Mensual using "${dir}\resultados\inflacionverdadera_venezuela_`cat'.xls", firstrow(variables) replace

}

}
