***********************************************************************************
*InflacionVerdadera.com
*SCRIPT: Indice de Precios Venezuela - Por Categoria
*Fecha: Junio 2017
*Nota: Esta version usa los indices por categorias creados antes y los pondera con los pesos oficiales
***********************************************************************************

clear
****SETUP***********
**Configurar el directorio donde esta la data
global dir "C:\inflacionverdadera\venezuela"
gen cat=.

forvalues cat=1(1)13 {
capture noisily {
display "`cat'"
append using ${dir}\resultados\index_`cat'.dta
replace cat=`cat' if cat==.
}
}

*Quedarse con la ultima observacion por categoria. 
capture drop maxdate 
bysort cat: egen maxdate=max(date)
keep if date==maxdate

*Reordenar las variables
keep cat category index mensual mindate maxdate days unique*
order cat category mindate maxdate unique* days index mensual 

*Traer ponderaciones y recalcularlas si hay una categoria sin data
merge m:1 cat using "${dir}\ponderaciones.dta"
keep if _merge==3
drop _merge

*Recalcular ponderaciones, en caso de que haya un sector sin data. 
egen sumweights=total(weight)
gen relweight=(weight/sumweights)*100

*Formatear fechas
format mindate %td
format maxdate %td
sort cat


*********************************************************
*Guardar la data

*Graba Archivo en formato Stata
save "${dir}\resultados\index_weight.dta", replace

**Graba archivos para los graficos de la pagina web 
keep  cat category mindate maxdate unique_obs unique_ids unique_ciudad unique_tienda index mensual weight relweight
ren (category mindate maxdate unique_obs unique_ids unique_ciudad unique_tienda index mensual  weight relweight) (Categoria Inicio Fin Obs Productos Ciudades Tiendas Indice Mensual Ponderacion_original Ponderacion)
sort cat
expand 2 if _n == 1
sort cat

tostring Inicio, replace format(%td) force
tostring Fin, replace format(%td) force

foreach var in "Obs Productos Ciudades Tiendas" {
tostring `var', replace  force
}

foreach var in " Indice Mensual Ponderacion" {
tostring `var', replace  force format(%9.2fc)
}

replace Categoria ="string" in 1
replace Inicio ="string" in 1
replace Fin  ="string" in 1
replace Obs ="number" in 1
replace Productos ="number" in 1
replace Ciudades ="number" in 1
replace Tiendas ="number" in 1
replace Indice ="number" in 1
replace Mensual ="number" in 1
replace Ponderacion ="number" in 1

export delimited Categoria Mensual Inicio Fin Obs Productos Ciudades Tiendas Ponderacion using "${dir}\resultados\ven_table.csv", nolabel replace

*Grabar archivo para website
drop if Mensual =="number"
export excel Categoria Mensual Inicio Fin Obs Productos Ciudades Tiendas Ponderacion  using "${dir}\resultados\inflacionverdadera_venezuela_sectores.xls", replace firstrow(variables)
export excel Categoria Mensual Inicio Fin Obs Productos Ciudades Tiendas Ponderacion using "C:\Dropbox (MIT)\IFTTT\inflacionverdadera_venezuela_sectores.xls", replace firstrow(variables)


