***********************************************************************************
*InflacionVerdadera.com
*SCRIPT: Indice de Precios Venezuela - Por Categoria
*Fecha: Junio 2017
*Nota: Esta version usa los indices por categorias creados antes y los pondera con los pesos oficiales
***********************************************************************************


clear
****SETUP***********
**Configurar el directorio donde esta la data
global dir "C:\inflacionverdadera\venezuela"
gen cat=.

*carga los indices por categoria
forvalues cat=1(1)13 {
capture noisily{
display "`cat'"
append using ${dir}\resultados\index_`cat'_temp.dta
replace cat=`cat' if cat==.
}
}

*Trae ponderaciones por categoria
merge m:1 category using "${dir}\ponderaciones.dta"
keep if _merge==3
drop _merge

levelsof cat, clean

*Agregar ponderaciones. En los ultimos dias no hay data para algunos sectores donde la recoleccion no termino. Asumimos que no hay cambios de precios para esos sectores. 
tsset cat date
tsfill, full
bysort cat: egen maxweight=max(weight)
drop weight
ren maxweight weight
replace mean_all=1 if mean_all==.
bysort date: egen sumweights=total(weight)
gen relweight=weight/sumweights
gen incidence=mean_all*relweight
bysort date: egen all_mean_all=total(incidence)
keep date all_mean_all
ren all_mean_all mean_all

*Dejar una observacion por dia. 
egen tag = tag(date)
keep if tag==1

*Crear indice a partir del dia 30 porque algunas categorias tienen recoleccion mensual
egen daymin=min(date)
replace daymin=daymin+30
drop if date<daymin
gen index=100 if date==daymin
drop daymin

replace mean_all=1 if mean_all==.
replace index=mean_all*index[_n-1] if index==.
label var index "Indice"

***************************************
*Inflacion Mensual 
***************************************

sort date
tsset date

*Inflacion Mensual
gen mensual=100*(index-index[_n-30])/index[_n-30]
format mensual  %9.1f

egen mindate=min(date)
egen maxdate=max(date)
gen days=maxdate-mindate

*********************************************************
*Guardar la data
save "${dir}\resultados\index_temp.dta", replace

*Eliminar los ultimos 7 dias, ya que hay data que todavia no ha sido enviada/procesada
global now = date("$S_DATE","DMY")
drop if date>=$now-7

*Graba Archivo en formato Stata
save "${dir}\resultados\index.dta", replace

**Graba archivos para los graficos de la pagina web 
label var date "Date"
label var index "Index"
label var mensual "Monthly"

*Agregar la definicion de la variable para importar al grafico
expand 2 if _n == 1
sort date
tostring date, replace format(%tdDD/NN/YY) force
replace date="string" in 1

tostring index, replace format(%9.2f)  force
replace index="number" in 1

tostring mensual, replace format(%9.2f)  force
replace mensual="number" in 1

ren date Fecha
ren index Indice
ren mensual Mensual

export delimited Fecha Indice using "${dir}\resultados\ven_indice.csv", replace
export delimited Fecha Mensual using "${dir}\resultados\ven_mensual.csv",  replace

*Grabar archivo para website
drop if Mensual =="number"
export excel Fecha Indice Mensual using "${dir}\resultados\inflacionverdadera_venezuela.xls", firstrow(variables) replace
